==> gridcalengine-5.2.6.tar.gz: gridcalengine-5.2.6/GridCalEngine/IO/cim/cgmes/cgmes_v2_4_15/devices/petersen_coil.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.
# SPDX-License-Identifier: MPL-2.0

from GridCalEngine.IO.base.units import UnitMultiplier, UnitSymbol
from GridCalEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.earth_fault_compensator import EarthFaultCompensator
from GridCalEngine.IO.cim.cgmes.cgmes_enums import cgmesProfile, UnitSymbol, PetersenCoilModeKind


class PetersenCoil(EarthFaultCompensator):
	def __init__(self, rdfid='', tpe='PetersenCoil'):
		EarthFaultCompensator.__init__(self, rdfid, tpe)

		self.mode: PetersenCoilModeKind = None
		self.nominalU: float = None
		self.offsetCurrent: float = None
		self.positionCurrent: float = None
		self.xGroundMax: float = None
		self.xGroundMin: float = None
		self.xGroundNominal: float = None

		self.register_property(
			name='mode',
			class_type=PetersenCoilModeKind,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.none,
			description='''The mode of operation of the Petersen coil.''',
			profiles=[]
		)
		self.register_property(
			name='nominalU',
			class_type=float,
			multiplier=UnitMultiplier.k,
			unit=UnitSymbol.V,
			description='''Electrical voltage, can be both AC and DC.''',
			profiles=[]
		)
		self.register_property(
			name='offsetCurrent',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.A,
			description='''Electrical current with sign convention: positive flow is out of the conducting equipment into the connectivity node. Can be both AC and DC.''',
			profiles=[]
		)
		self.register_property(
			name='positionCurrent',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.A,
			description='''Electrical current with sign convention: positive flow is out of the conducting equipment into the connectivity node. Can be both AC and DC.''',
			profiles=[]
		)
		self.register_property(
			name='xGroundMax',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.ohm,
			description='''Reactance (imaginary part of impedance), at rated frequency.''',
			profiles=[]
		)
		self.register_property(
			name='xGroundMin',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.ohm,
			description='''Reactance (imaginary part of impedance), at rated frequency.''',
			profiles=[]
		)
		self.register_property(
			name='xGroundNominal',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.ohm,
			description='''Reactance (imaginary part of impedance), at rated frequency.''',
			profiles=[]
		)

==> gridcalengine-5.3.2.tar.gz: gridcalengine-5.3.2/GridCalEngine/IO/cim/cgmes/cgmes_v3_0_0/devices/petersen_coil.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.
# SPDX-License-Identifier: MPL-2.0

from GridCalEngine.IO.base.units import UnitMultiplier, UnitSymbol
from GridCalEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.earth_fault_compensator import EarthFaultCompensator
from GridCalEngine.IO.cim.cgmes.cgmes_enums import cgmesProfile, PetersenCoilModeKind, UnitSymbol


class PetersenCoil(EarthFaultCompensator):
	def __init__(self, rdfid='', tpe='PetersenCoil'):
		EarthFaultCompensator.__init__(self, rdfid, tpe)

		self.mode: PetersenCoilModeKind = None
		self.nominalU: float = None
		self.offsetCurrent: float = None
		self.positionCurrent: float = None
		self.xGroundMax: float = None
		self.xGroundMin: float = None
		self.xGroundNominal: float = None

		self.register_property(
			name='mode',
			class_type=PetersenCoilModeKind,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.none,
			description='''The mode of operation of the Petersen coil.''',
			profiles=[]
		)
		self.register_property(
			name='nominalU',
			class_type=float,
			multiplier=UnitMultiplier.k,
			unit=UnitSymbol.V,
			description='''Electrical voltage, can be both AC and DC.''',
			profiles=[]
		)
		self.register_property(
			name='offsetCurrent',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.A,
			description='''Electrical current with sign convention: positive flow is out of the conducting equipment into the connectivity node. Can be both AC and DC.''',
			profiles=[]
		)
		self.register_property(
			name='positionCurrent',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.A,
			description='''Electrical current with sign convention: positive flow is out of the conducting equipment into the connectivity node. Can be both AC and DC.''',
			profiles=[]
		)
		self.register_property(
			name='xGroundMax',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.ohm,
			description='''Reactance (imaginary part of impedance), at rated frequency.''',
			profiles=[]
		)
		self.register_property(
			name='xGroundMin',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.ohm,
			description='''Reactance (imaginary part of impedance), at rated frequency.''',
			profiles=[]
		)
		self.register_property(
			name='xGroundNominal',
			class_type=float,
			multiplier=UnitMultiplier.none,
			unit=UnitSymbol.ohm,
			description='''Reactance (imaginary part of impedance), at rated frequency.''',
			profiles=[]
		)
